"use strict";
/*
tyron.js: SSI Protocol's JavaScript/TypeScript library
Self-Sovereign Identity Protocol.
Copyright (C) Tyron Pungtas and its affiliates.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const arweave_1 = __importDefault(require("arweave"));
const zcrypto = __importStar(require("@zilliqa-js/crypto"));
const document_model_1 = require("../did/protocols/models/document-model");
const tyronzil_1 = __importDefault(require("./tyronzil"));
const crypto_util_1 = __importDefault(require("./crypto-util"));
const { subtle } = require('crypto').webcrypto;
class DKMS {
    static operationKeyPair(arConnect, id, addr) {
        return __awaiter(this, void 0, void 0, function* () {
            const private_key = zcrypto.schnorr.generatePrivateKey();
            const public_key = '0x' + zcrypto.getPubKeyFromPrivateKey(private_key);
            const encrypted_key = yield DKMS.encryptKey(arConnect, private_key);
            const verification_method = {
                id: id,
                key: public_key,
                encrypted: encrypted_key,
            };
            const doc_element = {
                constructor: document_model_1.DocumentConstructor.VerificationMethod,
                action: document_model_1.Action.Add,
                key: verification_method,
            };
            const doc_parameter = yield tyronzil_1.default.documentParameter(addr, doc_element);
            return {
                element: doc_element,
                parameter: doc_parameter,
            };
        });
    }
    static generatePublicEncryption(privKey) {
        return __awaiter(this, void 0, void 0, function* () {
            let privateKey = Object.create(privKey);
            const algo = { name: 'RSA-OAEP', hash: { name: 'SHA-256' } };
            const keyData = {
                kty: 'RSA',
                e: 'AQAB',
                n: privateKey.n,
                alg: 'RSA-OAEP-256',
                ext: true,
            };
            const publicKey = yield subtle.importKey('jwk', keyData, algo, false, ['encrypt']);
            const keyBuf = yield crypto_util_1.default.generateRandomBytes(256);
            const encryptedPublicKey = yield subtle.encrypt({ name: 'RSA-OAEP' }, publicKey, keyBuf);
            let publicEncryption = arweave_1.default.utils.concatBuffers([
                encryptedPublicKey,
                keyBuf,
            ]);
            publicEncryption = arweave_1.default.utils.bufferTob64Url(publicEncryption);
            return publicEncryption;
        });
    }
    static generateSsiKeys(arweave) {
        return __awaiter(this, void 0, void 0, function* () {
            const privateKey = yield arweave.wallets.generate();
            const keyData = {
                kty: privateKey.kty,
                e: privateKey.e,
                n: privateKey.n,
                alg: 'RSA-OAEP-256',
                ext: true,
            };
            const algo = { name: 'RSA-OAEP', hash: { name: 'SHA-256' } };
            const publicKey = yield subtle.importKey('jwk', keyData, algo, false, ['encrypt']);
            const keyBuf = yield crypto_util_1.default.generateRandomBytes(256);
            const encryptedPublicKey = yield subtle.encrypt({ name: 'RSA-OAEP' }, publicKey, keyBuf);
            let publicEncryption = arweave_1.default.utils.concatBuffers([
                encryptedPublicKey,
                keyBuf,
            ]);
            publicEncryption = arweave_1.default.utils.bufferTob64Url(publicEncryption);
            return {
                privateKey: privateKey,
                publicEncryption: publicEncryption,
            };
        });
    }
    static encryptKey(arConnect, key) {
        return __awaiter(this, void 0, void 0, function* () {
            let encryptedKey = yield arConnect.encrypt(key, {
                algorithm: 'RSA-OAEP',
                hash: 'SHA-256',
            });
            encryptedKey = arweave_1.default.utils.bufferTob64Url(encryptedKey);
            return encryptedKey;
        });
    }
    static decryptKey(arConnect, encryptedKey) {
        return __awaiter(this, void 0, void 0, function* () {
            const encryptedArray = arweave_1.default.utils.b64UrlToBuffer(encryptedKey);
            const decryptedKey = yield arConnect.decrypt(encryptedArray, {
                algorithm: 'RSA-OAEP',
                hash: 'SHA-256',
            });
            return decryptedKey;
        });
    }
    static encryptData(data, publicEncryption) {
        return __awaiter(this, void 0, void 0, function* () {
            const publicEnc = arweave_1.default.utils.b64UrlToBuffer(publicEncryption);
            const encKey = new Uint8Array(publicEnc.slice(0, 512));
            const keyBuf = new Uint8Array(publicEnc.slice(512));
            const contentBuf = new TextEncoder().encode(JSON.stringify(data));
            const encryptedContent = yield arweave_1.default.crypto.encrypt(contentBuf, keyBuf);
            let encryptedData = arweave_1.default.utils.concatBuffers([
                encKey,
                encryptedContent,
            ]);
            encryptedData = arweave_1.default.utils.bufferTob64Url(encryptedData);
            return encryptedData;
        });
    }
    static decryptData(data, decKey) {
        return __awaiter(this, void 0, void 0, function* () {
            const encryptedArray = arweave_1.default.utils.b64UrlToBuffer(data);
            let encryptedBuffer = encryptedArray.buffer;
            const encKey = new Uint8Array(encryptedBuffer.slice(0, 512));
            const encryptedData = new Uint8Array(encryptedBuffer.slice(512));
            let key = Object.create(decKey);
            key.alg = 'RSA-OAEP-256';
            key.ext = true;
            const algo = { name: 'RSA-OAEP', hash: { name: 'SHA-256' } };
            key = yield subtle.importKey('jwk', key, algo, false, [
                'decrypt',
            ]);
            const symmetricKey = yield subtle.decrypt({ name: 'RSA-OAEP' }, key, encKey);
            let decryptedData = yield arweave_1.default.crypto.decrypt(encryptedData, symmetricKey);
            decryptedData = arweave_1.default.utils.bufferToString(decryptedData);
            return decryptedData;
        });
    }
}
exports.default = DKMS;
//# sourceMappingURL=dkms.js.map