"use strict";
/*
tyron.js: SSI Protocol's JavaScript/TypeScript library
Self-Sovereign Identity Protocol
Copyright (C) Tyron Mapu Community Interest Company and its affiliates.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/** Tools to manage smart contracts */
const resolver_1 = __importDefault(require("../did/operations/did-resolve/resolver"));
const did_scheme_1 = require("../did/tyronzil-schemes/did-scheme");
const state_1 = __importDefault(require("./state"));
const zilliqa_init_1 = __importDefault(require("./zilliqa-init"));
class SearchBarUtil {
    static fetchAddr(net, _username, _domain) {
        return __awaiter(this, void 0, void 0, function* () {
            let network = did_scheme_1.NetworkNamespace.Mainnet;
            let init_tyron = '0xdfc81a41a7a1ce6ed99e27f9aa1ede4f6d97c7d0'; //@todo-x
            if (net === 'testnet') {
                network = did_scheme_1.NetworkNamespace.Testnet;
                init_tyron = '0x26193045954FFdf23859c679c29ad164932ADdA1';
            }
            const addr = yield resolver_1.default.resolveDns(network, init_tyron.toLowerCase(), _username, _domain).catch((err) => {
                throw err;
            });
            return addr;
        });
    }
    static Resolve(net, addr) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let network = did_scheme_1.NetworkNamespace.Mainnet;
            if (net === 'testnet') {
                network = did_scheme_1.NetworkNamespace.Testnet;
            }
            const did_doc = [];
            const state = yield state_1.default.fetch(network, addr);
            let did;
            if (state.did == '') {
                did = 'Not activated yet';
            }
            else {
                did = state.did;
            }
            did_doc.push(['Decentralized identifier', did]);
            const controller = state.controller;
            if (state.services_ && ((_a = state.services_) === null || _a === void 0 ? void 0 : _a.size) !== 0) {
                const services = Array();
                for (const id of state.services_.keys()) {
                    const result = state.services_.get(id);
                    if (result && result[1] !== undefined) {
                        services.push([id, result]);
                    }
                    else if (result && result[1] === undefined) {
                        let val;
                        val = result[0];
                        services.push([id, val.arguments[0]]);
                    }
                }
                did_doc.push(['DID services', services]);
            }
            if (state.verification_methods) {
                if (state.verification_methods.get('socialrecovery')) {
                    did_doc.push([
                        'social-recovery key',
                        [state.verification_methods.get('socialrecovery')],
                    ]);
                }
                if (state.verification_methods.get('update')) {
                    did_doc.push([
                        'update key',
                        [state.verification_methods.get('update')],
                    ]);
                }
                if (state.verification_methods.get('dex')) {
                    did_doc.push([
                        'decentralized-exchange key',
                        [state.verification_methods.get('dex')],
                    ]);
                }
                if (state.verification_methods.get('stake')) {
                    did_doc.push([
                        'staking key',
                        [state.verification_methods.get('stake')],
                    ]);
                }
                if (state.verification_methods.get('general')) {
                    did_doc.push([
                        'general-purpose key',
                        [state.verification_methods.get('general')],
                    ]);
                }
                if (state.verification_methods.get('authentication')) {
                    did_doc.push([
                        'authentication key',
                        [state.verification_methods.get('authentication')],
                    ]);
                }
                if (state.verification_methods.get('assertion')) {
                    did_doc.push([
                        'assertion key',
                        [state.verification_methods.get('assertion')],
                    ]);
                }
                if (state.verification_methods.get('agreement')) {
                    did_doc.push([
                        'agreement key',
                        [state.verification_methods.get('agreement')],
                    ]);
                }
                if (state.verification_methods.get('invocation')) {
                    did_doc.push([
                        'invocation key',
                        [state.verification_methods.get('invocation')],
                    ]);
                }
                if (state.verification_methods.get('delegation')) {
                    did_doc.push([
                        'delegation key',
                        [state.verification_methods.get('delegation')],
                    ]);
                }
                if (state.verification_methods.get('vc')) {
                    did_doc.push([
                        'verifiable-credential key',
                        [state.verification_methods.get('vc')],
                    ]);
                }
                if (state.verification_methods.get('defi')) {
                    did_doc.push([
                        'decentralized-finance key',
                        [state.verification_methods.get('defi')],
                    ]);
                }
            }
            const init = new zilliqa_init_1.default(network);
            let guardians = [];
            try {
                const social_recovery = yield init.API.blockchain.getSmartContractSubState(addr, 'social_guardians');
                guardians = yield this.resolveSubState(social_recovery.result.social_guardians);
            }
            catch (error) {
                throw error;
            }
            let version = '0';
            yield init.API.blockchain
                .getSmartContractSubState(addr, 'version')
                .then((substate) => {
                if (substate.result !== null) {
                    version = substate.result.version;
                    if (Number(version.slice(8, 9)) >= 4 ||
                        version.slice(0, 4) === 'init' ||
                        version.slice(0, 3) === 'dao') {
                        console.log(`DID Document version: ${version.slice(8, 11)}`);
                        console.log(`Address: ${addr}`);
                    }
                    else {
                        throw new Error('Upgrade required: deploy a new SSI.');
                    }
                }
                else {
                    throw new Error('Upgrade required: deploy a new SSI.');
                }
            })
                .catch((error) => {
                throw error;
            });
            return {
                did: did,
                version: version,
                status: state.did_status,
                controller: controller,
                doc: did_doc,
                dkms: state.dkms,
                guardians: guardians,
            };
        });
    }
    static resolveSubState(object) {
        return __awaiter(this, void 0, void 0, function* () {
            const entries = Object.entries(object);
            const result = [];
            entries.forEach((value) => {
                result.push(value[0]);
            });
            return result;
        });
    }
}
exports.default = SearchBarUtil;
SearchBarUtil.isValidUsername = (username) => (/^[\w\d_]+$/.test(username) && username.length > 5) ||
    username === 'init' ||
    username === 'tyron' ||
    username === 'wfp';
SearchBarUtil.isAdminUsername = (username) => username === 'init' || username === 'tyron' || username === 'wfp';
//# sourceMappingURL=searchbar-util.js.map