"use strict";
/*
tyron.js: SSI Protocol's JavaScript/TypeScript library
Self-Sovereign Identity Protocol.
Copyright (C) Tyron Pungtas and its affiliates.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/** Tools to manage smart contracts */
class SmartUtil {
    /** Gets the value out of a field Option */
    static getValue(object) {
        return __awaiter(this, void 0, void 0, function* () {
            const entries = Object.entries(object);
            let result;
            entries.forEach((value) => {
                if (value[0] === 'arguments') {
                    result = value[1];
                }
            });
            return result[0];
        });
    }
    /** Gets the DID Status out of field Option */
    static getStatus(object) {
        return __awaiter(this, void 0, void 0, function* () {
            const entries = Object.entries(object);
            let result;
            entries.forEach((value) => {
                if (value[0] === 'constructor') {
                    result = value[1];
                }
            });
            const status = result.split('.');
            return status[1];
        });
    }
    /** Gets the value out of a map key */
    static getValuefromMap(object, key) {
        return __awaiter(this, void 0, void 0, function* () {
            const entries = Object.entries(object);
            let result;
            entries.forEach((value) => {
                if (value[0] === key) {
                    result = value[1];
                }
            });
            return result;
        });
    }
    /** Turns the smart contract's map into a Map */
    static intoMap(object) {
        return __awaiter(this, void 0, void 0, function* () {
            const entries = Object.entries(object);
            let map = new Map();
            entries.forEach((value) => {
                map.set(value[0], value[1]);
            });
            return map;
        });
    }
    /** Turns the DID's services map field into a Map */
    static fromServices(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const prev_map = yield this.intoMap(input);
            let map = new Map();
            for (let id of prev_map.keys()) {
                const object = prev_map.get(id);
                const entries = Object.entries(object);
                entries.forEach((value) => {
                    if (value[0] === 'arguments') {
                        const result = value[1];
                        const type = result[0];
                        const uri = result[2];
                        map.set(id, [type, uri]);
                    }
                });
            }
            return map;
        });
    }
}
exports.default = SmartUtil;
//# sourceMappingURL=smart-util.js.map