"use strict";
/*
tyron.js: SSI Protocol's JavaScript/TypeScript library
Self-Sovereign Identity Protocol.
Copyright (C) Tyron Pungtas and its affiliates.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const zilliqa_init_1 = __importDefault(require("./zilliqa-init"));
const smart_util_1 = __importDefault(require("./smart-util"));
const sidetree_1 = require("../did/protocols/sidetree");
const ErrorCode_1 = __importDefault(require("../did/util/ErrorCode"));
class State {
    constructor(state) {
        this.did = state.did;
        this.controller = state.controller;
        this.did_status = state.did_status;
        this.verification_methods = state.verification_methods;
        this.dkms = state.dkms;
        this.services = state.services;
        this.services_ = state.services_;
    }
    /** Fetches the current state from the blockchain
     * @params addr: the Zilliqa address of the user's smart-contract
     */
    static fetch(network, addr) {
        return __awaiter(this, void 0, void 0, function* () {
            const ZIL_INIT = new zilliqa_init_1.default(network);
            const state = yield ZIL_INIT.API.blockchain
                .getSmartContractState(addr)
                .then((state_) => __awaiter(this, void 0, void 0, function* () {
                const STATUS = yield smart_util_1.default.getStatus(state_.result.did_status);
                switch (STATUS) {
                    case sidetree_1.DIDStatus.Deactivated:
                        throw new ErrorCode_1.default('DidDeactivated', 'The requested DID is deactivated');
                    default:
                        let dkms = undefined;
                        if (state_.result.dkms !== undefined) {
                            dkms = yield smart_util_1.default.intoMap(state_.result.dkms);
                        }
                        const STATE = {
                            did: String(state_.result.did),
                            controller: String(state_.result.controller),
                            did_status: STATUS,
                            verification_methods: yield smart_util_1.default.intoMap(state_.result.verification_methods),
                            dkms: dkms,
                            services: yield smart_util_1.default.intoMap(state_.result.services),
                            services_: yield smart_util_1.default.fromServices(state_.result.services_),
                        };
                        return new State(STATE);
                }
            }))
                .catch((err) => {
                throw err;
            });
            return state;
        });
    }
}
exports.default = State;
//# sourceMappingURL=state.js.map