/// <reference types="bn.js" />
/// <reference types="long" />
import { Transaction } from '@zilliqa-js/account';
import { Contract } from '@zilliqa-js/contract';
import * as zutil from '@zilliqa-js/util';
import ZilliqaInit from './zilliqa-init';
import { NetworkNamespace } from '../did/tyronzil-schemes/did-scheme';
import { DocumentElement, TransferProtocol } from '../did/protocols/models/document-model';
/** tyronzil transaction class */
export default class TyronZIL extends ZilliqaInit {
    readonly controller: string;
    readonly controllerSecretKey: string;
    readonly gasPrice: zutil.BN;
    readonly gasLimit: zutil.Long;
    readonly tyron: string;
    private constructor();
    /** Retrieves the minimum gas price & validates the account info */
    static initialize(network: NetworkNamespace, controllerSecretKey: string, gasLimit: number, tyron: string): Promise<TyronZIL>;
    static deploy(contractInit: any[], tyronzil: TyronZIL, contractCode: string): Promise<DeployedContract>;
    /** Submits a tyronzil transaction */
    static submit(tag: string, tyronzil: TyronZIL, addr: string, amount: string, params: TransitionParams[] | []): Promise<Transaction>;
    /** Returns a DID Document element as transition parameter */
    static documentParameter(addr: string, element: DocumentElement): Promise<TransitionValue>;
    static OptionParam(option: Option, argtype: string, args?: any): Promise<TransitionValue>;
    static CrudParams(addr: string, document: TransitionValue[], signature: any, tyron: TransitionValue): Promise<TransitionParams[]>;
    static BuyNftUsername(username: string, addr: TransitionValue, id: string, tyron: TransitionValue): Promise<TransitionParams[]>;
    static TransferNftUsername(username: string, guardianship: TransitionValue, id: string, addr: string, dID: string, tyron: TransitionValue, docVersion: any): Promise<TransitionParams[]>;
    static GetBeneficiary(addr: string, beneficiary: Beneficiary): Promise<TransitionValue>;
    static Transfer(addr: string, addrName: string, beneficiary: Beneficiary, amount: string, tyron: TransitionValue): Promise<TransitionParams[]>;
    static SendFunds(addr: string, tag: string, beneficiary: Beneficiary, amount: string, tyron: TransitionValue): Promise<TransitionParams[]>;
    static NftTransfer(addr: string, beneficiary: Beneficiary): Promise<TransitionParams[]>;
    static ConfigureSocialRecovery(guardians: string[], sig: string, tyron: TransitionValue): Promise<TransitionParams[]>;
    static EnableSocialRecovery(addr1: string, addr2: string): Promise<TransitionParams[]>;
    static GetRecoverer(addr: string, recoverer: Recoverer): Promise<TransitionValue>;
    static UpdateSocialRecoverer(addr: string, recoverer: Recoverer, addr1: string): Promise<TransitionParams[]>;
    static SocialRecovery(addr: string, signature1: string, signature2: string): Promise<TransitionParams[]>;
    static TxAddr(addr: string): Promise<TransitionParams[]>;
    static TxAmount(amount: string): Promise<TransitionParams[]>;
    static AddWork(addr: string, transferProtocol: TransferProtocol, uri: string, amount: string): Promise<TransitionParams[]>;
    static AssessPerformance(commit: string, amount: string): Promise<TransitionParams[]>;
    static RemoveService(commit: string): Promise<TransitionParams[]>;
    static Dns(addr: string, domain: string, didKey: string, encrypted: string, tyron: TransitionValue): Promise<TransitionParams[]>;
    static AddFunds(to: string, amount: string): Promise<TransitionParams[]>;
    static DidSocialRecovery(addr: string, signatures: any, tyron: TransitionValue): Promise<TransitionParams[]>;
    static Allowances(addrName: string, spender: string, amount: string, tyron: TransitionValue): Promise<TransitionParams[]>;
    static Lock(signature: string, tyron: TransitionValue): Promise<TransitionParams[]>;
    static Treasury(username: string, signature: string): Promise<TransitionParams[]>;
    static Ivms101(username: string, message: string, signature: string): Promise<TransitionParams[]>;
    static VerifiableCredential(username: string, signature: string): Promise<TransitionParams[]>;
}
/** The result of a contract deployment */
export interface DeployedContract {
    transaction: Transaction;
    contract: Contract;
    gas: any;
}
export interface TransitionParams {
    vname: string;
    type: string;
    value: unknown;
}
export interface TransitionValue {
    argtypes: any[];
    arguments: any[];
    constructor: string;
}
export declare enum Option {
    some = "Some",
    none = "None"
}
export declare enum Recoverer {
    first = "First",
    second = "Second"
}
export declare enum BeneficiaryConstructor {
    NftUsername = "NftUsername",
    Recipient = "Recipient"
}
export interface Beneficiary {
    constructor: BeneficiaryConstructor;
    username?: string;
    domain?: string;
    addr?: string;
}
