"use strict";
/*
tyron.js: SSI Protocol's JavaScript/TypeScript library
Tyron Self-Sovereign Identity Protocol
Copyright (C) Tyron Pungtas and its affiliates.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BeneficiaryConstructor = exports.Recoverer = exports.Option = void 0;
const zcrypto = __importStar(require("@zilliqa-js/crypto"));
const zutil = __importStar(require("@zilliqa-js/util"));
const zilliqa_init_1 = __importDefault(require("./zilliqa-init"));
const ErrorCode_1 = __importDefault(require("../did/util/ErrorCode"));
const document_model_1 = require("../did/protocols/models/document-model");
/** tyronzil transaction class */
class TyronZIL extends zilliqa_init_1.default {
    constructor(network, controller, controllerSecretKey, gasPrice, gasLimit, init_tyron) {
        super(network);
        this.controller = controller;
        this.controllerSecretKey = controllerSecretKey;
        this.gasPrice = gasPrice;
        this.gasLimit = gasLimit;
        this.tyron = init_tyron;
    }
    /** Retrieves the minimum gas price & validates the account info */
    static initialize(network, controllerSecretKey, gasLimit, tyron) {
        return __awaiter(this, void 0, void 0, function* () {
            let controller = zcrypto.getAddressFromPrivateKey(controllerSecretKey);
            const gas_limit = new zutil.Long(gasLimit);
            const zil_init = new zilliqa_init_1.default(network);
            const transaction_init = yield zil_init.API.blockchain
                .getMinimumGasPrice()
                .then((min_gas_price) => {
                const gas_price = new zutil.BN(min_gas_price.result);
                return new TyronZIL(network, controller, controllerSecretKey, gas_price, gas_limit, tyron);
            })
                .catch((err) => {
                throw err;
            });
            return transaction_init;
        });
    }
    static deploy(contractInit, tyronzil, contractCode) {
        return __awaiter(this, void 0, void 0, function* () {
            const smart_contract = tyronzil.API.contracts.new(contractCode, contractInit);
            tyronzil.API.wallet.addByPrivateKey(tyronzil.controllerSecretKey);
            const deployed_contract = yield tyronzil.API.blockchain
                .getBalance(tyronzil.controller)
                .then((account) => __awaiter(this, void 0, void 0, function* () {
                const [deployTx, contract] = yield smart_contract.deploy({
                    version: tyronzil.zilVersion,
                    gasPrice: tyronzil.gasPrice,
                    gasLimit: tyronzil.gasLimit,
                    nonce: Number(account.result.nonce) + 1,
                }, 33, 1000, false);
                const is_deployed = deployTx.isConfirmed();
                if (!is_deployed) {
                    throw new ErrorCode_1.default('Wrong-Deployment', 'The contract did not get deployed.');
                }
                const deployment_gas = deployTx.getReceipt().cumulative_gas;
                const deployed_contract = {
                    transaction: deployTx,
                    contract: contract,
                    gas: deployment_gas,
                };
                return deployed_contract;
            }))
                .catch((err) => {
                throw err;
            });
            return deployed_contract;
        });
    }
    /** Submits a tyronzil transaction */
    static submit(tag, tyronzil, addr, amount, params) {
        return __awaiter(this, void 0, void 0, function* () {
            const submit = yield tyronzil.API.blockchain
                .getSmartContractState(addr)
                .then((_smart_contract_state) => __awaiter(this, void 0, void 0, function* () {
                //@to-do throw error if status is Deactivated
                const amount_ = new zutil.BN(amount);
                const pubkey = zcrypto.getPubKeyFromPrivateKey(tyronzil.controllerSecretKey);
                const zil_account = yield tyronzil.API.blockchain.getBalance(tyronzil.controller);
                const transition = {
                    _tag: tag,
                    _amount: String(amount_),
                    _sender: tyronzil.controller,
                    params: params,
                };
                const tx_object = {
                    version: tyronzil.zilVersion,
                    amount: amount_,
                    nonce: Number(zil_account.result.nonce) + 1,
                    gasLimit: tyronzil.gasLimit,
                    gasPrice: tyronzil.gasPrice,
                    toAddr: addr,
                    pubKey: pubkey,
                    data: JSON.stringify(transition),
                };
                return tyronzil.API.transactions.new(tx_object);
            }))
                .then((raw_tx) => __awaiter(this, void 0, void 0, function* () {
                tyronzil.API.wallet.addByPrivateKey(tyronzil.controllerSecretKey);
                return yield tyronzil.API.wallet.signWith(raw_tx, tyronzil.controller);
            }))
                .then((signed_tx) => __awaiter(this, void 0, void 0, function* () {
                /** Sends the tyronzil transaction to the Zilliqa blockchain platform */
                return yield tyronzil.API.blockchain.createTransaction(signed_tx, 33, 1000);
            }))
                .then((transaction) => __awaiter(this, void 0, void 0, function* () {
                const tx_id = transaction.id;
                const transaction_ = yield transaction.confirm(tx_id, 33, 1000);
                const status = transaction.isConfirmed();
                if (!status) {
                    throw new ErrorCode_1.default('TyronZIL', `The ${tag} tyronZIL transaction was unsuccessful!`);
                }
                return transaction_;
            }))
                .catch((err) => {
                throw err;
            });
            return submit;
        });
    }
    /** Returns a DID Document element as transition parameter */
    static documentParameter(addr, element) {
        return __awaiter(this, void 0, void 0, function* () {
            let add = {
                argtypes: [],
                arguments: [],
                constructor: `${addr.toLowerCase()}.${document_model_1.Action.Add}`,
            };
            let remove = {
                argtypes: [],
                arguments: [],
                constructor: `${addr.toLowerCase()}.${document_model_1.Action.Remove}`,
            };
            let value = {
                argtypes: [],
                arguments: [],
                constructor: `${addr.toLowerCase()}.${element.constructor}`,
            };
            switch (element.constructor) {
                case 'VerificationMethod':
                    switch (element.action) {
                        case document_model_1.Action.Add:
                            Object.assign(value, {
                                arguments: [
                                    add,
                                    `${element.key.id}`,
                                    `${element.key.key}`,
                                    `${element.key.encrypted}`,
                                ],
                            });
                            break;
                        case document_model_1.Action.Remove:
                            Object.assign(value, {
                                arguments: [
                                    remove,
                                    `${element.key.id}`,
                                    '0x024caf04aa4f660db04adf65daf5b993b3383fcdb2ef0479ca8866b1336334b5b4',
                                    'none',
                                ],
                            });
                            break;
                    }
                    break;
                case 'Service':
                    let endpoint;
                    switch (element.service.endpoint) {
                        case 'Address':
                            endpoint = {
                                argtypes: [],
                                arguments: [
                                    {
                                        argtypes: [],
                                        arguments: [`${element.service.val}`],
                                        constructor: `${addr.toLowerCase()}.${element.service.blockchainType}`,
                                    },
                                ],
                                constructor: `${addr.toLowerCase()}.Address`,
                            };
                            break;
                        case 'Uri':
                            endpoint = {
                                argtypes: [],
                                arguments: [
                                    `${element.service.type}`,
                                    {
                                        argtypes: [],
                                        arguments: [],
                                        constructor: `${addr.toLowerCase()}.${element.service.transferProtocol}`,
                                    },
                                    `${element.service.val}`,
                                ],
                                constructor: `${addr.toLowerCase()}.Uri`,
                            };
                            break;
                    }
                    const remove_uri = {
                        argtypes: [],
                        arguments: [
                            `remove`,
                            {
                                argtypes: [],
                                arguments: [],
                                constructor: `${addr.toLowerCase()}.${document_model_1.TransferProtocol.Https}`,
                            },
                            `remove`,
                        ],
                        constructor: `${addr.toLowerCase()}.Uri`,
                    };
                    switch (element.action) {
                        case document_model_1.Action.Add:
                            Object.assign(value, {
                                arguments: [
                                    add,
                                    `${element.service.id}`,
                                    endpoint,
                                ],
                            });
                            break;
                        case document_model_1.Action.Remove:
                            Object.assign(value, {
                                arguments: [
                                    remove,
                                    `${element.service.id}`,
                                    remove_uri,
                                ],
                            });
                            break;
                    }
                    break;
                default:
                    throw new ErrorCode_1.default('UnsupportedElement', 'That is not a DID-Document supported element');
            }
            return value;
        });
    }
    static OptionParam(option, argtype, args) {
        return __awaiter(this, void 0, void 0, function* () {
            let value;
            switch (option) {
                case Option.some:
                    value = {
                        argtypes: [`${argtype}`],
                        arguments: [args],
                        constructor: 'Some',
                    };
                    break;
                case Option.none:
                    value = {
                        argtypes: [`${argtype}`],
                        arguments: [],
                        constructor: 'None',
                    };
                    break;
            }
            return value;
        });
    }
    static CrudParams(addr, document, signature, tyron) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const doc = {
                vname: 'document',
                type: `List ${addr.toLowerCase()}.Document`,
                value: document,
            };
            params.push(doc);
            const sig = {
                vname: 'signature',
                type: 'Option ByStr64',
                value: signature,
            };
            params.push(sig);
            const tyron_ = {
                vname: 'tyron',
                type: 'Option Uint128',
                value: tyron,
            };
            params.push(tyron_);
            return params;
        });
    }
    static BuyNftUsername(username, addr, id, tyron) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const username_ = {
                vname: 'username',
                type: 'String',
                value: username,
            };
            params.push(username_);
            const addr_ = {
                vname: 'addr',
                type: 'Option ByStr20',
                value: addr,
            };
            params.push(addr_);
            const id_ = {
                vname: 'id',
                type: 'String',
                value: id,
            };
            params.push(id_);
            const tyron_ = {
                vname: 'tyron',
                type: 'Option Uint128',
                value: tyron,
            };
            params.push(tyron_);
            return params;
        });
    }
    static TransferNftUsername(username, guardianship, id, addr, dID, tyron, docVersion) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const username_ = {
                vname: 'username',
                type: 'String',
                value: username,
            };
            params.push(username_);
            const id_ = {
                vname: 'id',
                type: 'String',
                value: id,
            };
            params.push(id_);
            if (Number(docVersion.slice(8, 9)) < 5) {
                const addr_ = {
                    vname: 'newAddr',
                    type: 'ByStr20',
                    value: addr,
                };
                params.push(addr_);
                const guardianship_ = {
                    vname: 'guardianship',
                    type: 'Option ByStr20',
                    value: guardianship,
                };
                params.push(guardianship_);
                if ((Number(docVersion.slice(8, 9)) >= 4 &&
                    Number(docVersion.slice(10, 11)) <= 6) ||
                    docVersion.slice(0, 3) === 'dao') {
                    const amount_ = {
                        vname: 'amount',
                        type: 'Uint128',
                        value: '0',
                    };
                    params.push(amount_);
                }
            }
            else {
                const addr_ = {
                    vname: 'addr',
                    type: 'ByStr20',
                    value: addr,
                };
                params.push(addr_);
                const dID_ = {
                    vname: 'dID',
                    type: 'ByStr20',
                    value: dID,
                };
                params.push(dID_);
            }
            const tyron_ = {
                vname: 'tyron',
                type: 'Option Uint128',
                value: tyron,
            };
            params.push(tyron_);
            return params;
        });
    }
    static GetBeneficiary(addr, beneficiary) {
        return __awaiter(this, void 0, void 0, function* () {
            let beneficiary_ = {
                argtypes: [],
                arguments: [],
                constructor: `${addr.toLowerCase()}.${beneficiary.constructor}`,
            };
            switch (beneficiary.constructor) {
                case 'NftUsername':
                    Object.assign(beneficiary_, {
                        arguments: [beneficiary.username, beneficiary.domain],
                    });
                    break;
                case 'Recipient':
                    Object.assign(beneficiary_, {
                        arguments: [beneficiary.addr],
                    });
                    break;
            }
            return beneficiary_;
        });
    }
    static Transfer(addr, addrName, beneficiary, amount, tyron) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const addr_name = {
                vname: 'addrName',
                type: 'String',
                value: addrName,
            };
            params.push(addr_name);
            const beneficiary__ = {
                vname: 'beneficiary',
                type: `${addr.toLowerCase()}.Beneficiary`,
                value: yield this.GetBeneficiary(addr, beneficiary),
            };
            params.push(beneficiary__);
            const amount_ = {
                vname: 'amount',
                type: 'Uint128',
                value: amount,
            };
            params.push(amount_);
            const tyron_ = {
                vname: 'tyron',
                type: 'Option Uint128',
                value: tyron,
            };
            params.push(tyron_);
            return params;
        });
    }
    static SendFunds(addr, tag, beneficiary, amount, tyron) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const tag_ = {
                vname: 'tag',
                type: 'String',
                value: tag,
            };
            params.push(tag_);
            const beneficiary__ = {
                vname: 'beneficiary',
                type: `${addr.toLowerCase()}.Beneficiary`,
                value: yield this.GetBeneficiary(addr, beneficiary),
            };
            params.push(beneficiary__);
            const amount_ = {
                vname: 'amount',
                type: 'Uint128',
                value: amount,
            };
            params.push(amount_);
            const tyron_ = {
                vname: 'tyron',
                type: 'Option Uint128',
                value: tyron,
            };
            params.push(tyron_);
            return params;
        });
    }
    static NftTransfer(addr, beneficiary) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const beneficiary__ = {
                vname: 'beneficiary',
                type: `${addr.toLowerCase()}.Beneficiary`,
                value: yield this.GetBeneficiary(addr, beneficiary),
            };
            params.push(beneficiary__);
            return params;
        });
    }
    static ConfigureSocialRecovery(guardians, sig, tyron) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const guardians_ = {
                vname: 'guardians',
                type: 'List ByStr32',
                value: guardians,
            };
            params.push(guardians_);
            const sig_ = {
                vname: 'sig',
                type: 'ByStr64',
                value: sig,
            };
            params.push(sig_);
            const tyron_ = {
                vname: 'tyron',
                type: 'Option Uint128',
                value: tyron,
            };
            params.push(tyron_);
            return params;
        });
    }
    static EnableSocialRecovery(addr1, addr2) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const addr1_ = {
                vname: 'addr1',
                type: 'ByStr20',
                value: addr1,
            };
            params.push(addr1_);
            const addr2_ = {
                vname: 'addr2',
                type: 'ByStr20',
                value: addr2,
            };
            params.push(addr2_);
            return params;
        });
    }
    static GetRecoverer(addr, recoverer) {
        return __awaiter(this, void 0, void 0, function* () {
            return {
                argtypes: [],
                arguments: [],
                constructor: `${addr.toLowerCase()}.${recoverer}`,
            };
        });
    }
    static UpdateSocialRecoverer(addr, recoverer, addr1) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const recoverer__ = {
                vname: 'recoverer',
                type: `${addr.toLowerCase()}.Recoverer`,
                value: yield this.GetRecoverer(addr, recoverer),
            };
            params.push(recoverer__);
            const addr_ = {
                vname: 'addr',
                type: 'ByStr20',
                value: addr1,
            };
            params.push(addr_);
            return params;
        });
    }
    static SocialRecovery(addr, signature1, signature2) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const addr_ = {
                vname: 'addr',
                type: 'ByStr20',
                value: addr,
            };
            params.push(addr_);
            const sig1 = {
                vname: 'signature1',
                type: 'ByStr64',
                value: signature1,
            };
            params.push(sig1);
            const sig2 = {
                vname: 'signature2',
                type: 'ByStr64',
                value: signature2,
            };
            params.push(sig2);
            return params;
        });
    }
    static TxAddr(addr) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const addr_ = {
                vname: 'addr',
                type: 'ByStr20',
                value: addr,
            };
            params.push(addr_);
            return params;
        });
    }
    static TxAmount(amount) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const amount_ = {
                vname: 'amount',
                type: 'Uint128',
                value: amount,
            };
            params.push(amount_);
            return params;
        });
    }
    static AddWork(addr, transferProtocol, uri, amount) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const tprotocol = {
                argtypes: [],
                arguments: [],
                constructor: `${addr.toLowerCase()}.${transferProtocol}`,
            };
            const transfer_protocol = {
                vname: 'transferProtocol',
                type: `${addr.toLowerCase()}.TransferProtocol`,
                value: tprotocol,
            };
            params.push(transfer_protocol);
            const uri_ = {
                vname: 'uri',
                type: 'String',
                value: uri,
            };
            params.push(uri_);
            const amount_ = {
                vname: 'amount',
                type: 'Uint128',
                value: amount,
            };
            params.push(amount_);
            return params;
        });
    }
    static AssessPerformance(commit, amount) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const commit_ = {
                vname: 'commit',
                type: 'ByStr32',
                value: commit,
            };
            params.push(commit_);
            const amount_ = {
                vname: 'amount',
                type: 'Uint128',
                value: amount,
            };
            params.push(amount_);
            return params;
        });
    }
    static RemoveService(commit) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const commit_ = {
                vname: 'commit',
                type: 'ByStr32',
                value: commit,
            };
            params.push(commit_);
            return params;
        });
    }
    static Dns(addr, domain, didKey, encrypted, tyron) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const addr_ = {
                vname: 'addr',
                type: 'ByStr20',
                value: addr,
            };
            params.push(addr_);
            const did_key = {
                vname: 'didKey',
                type: 'ByStr33',
                value: didKey,
            };
            params.push(did_key);
            const encrypted_ = {
                vname: 'encrypted',
                type: 'String',
                value: encrypted,
            };
            params.push(encrypted_);
            const domain_ = {
                vname: 'domain',
                type: 'String',
                value: domain,
            };
            params.push(domain_);
            const tyron_ = {
                vname: 'tyron',
                type: 'Option Uint128',
                value: tyron,
            };
            params.push(tyron_);
            return params;
        });
    }
    static AddFunds(to, amount) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const to_ = {
                vname: 'to',
                type: 'ByStr20',
                value: to,
            };
            params.push(to_);
            const amount_ = {
                vname: 'amount',
                type: 'Uint128',
                value: amount,
            };
            params.push(amount_);
            return params;
        });
    }
    static DidSocialRecovery(addr, signatures, tyron) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const addr_ = {
                vname: 'addr',
                type: 'ByStr20',
                value: addr,
            };
            params.push(addr_);
            const signatures_ = {
                vname: 'signatures',
                type: 'List( Pair String ByStr64 )',
                value: signatures,
            };
            params.push(signatures_);
            const tyron_ = {
                vname: 'tyron',
                type: 'Option Uint128',
                value: tyron,
            };
            params.push(tyron_);
            return params;
        });
    }
    static Allowances(addrName, spender, amount, tyron) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const addrName_ = {
                vname: 'addrName',
                type: 'String',
                value: addrName,
            };
            params.push(addrName_);
            const spender_ = {
                vname: 'spender',
                type: 'ByStr20',
                value: spender,
            };
            params.push(spender_);
            const amount_ = {
                vname: 'amount',
                type: 'Uint128',
                value: amount,
            };
            params.push(amount_);
            const tyron_ = {
                vname: 'tyron',
                type: 'Option Uint128',
                value: tyron,
            };
            params.push(tyron_);
            return params;
        });
    }
    static Lock(signature, tyron) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const signature_ = {
                vname: 'signature',
                type: 'ByStr64',
                value: signature,
            };
            params.push(signature_);
            const tyron_ = {
                vname: 'tyron',
                type: 'Option Uint128',
                value: tyron,
            };
            params.push(tyron_);
            return params;
        });
    }
    static Treasury(username, signature) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const username_ = {
                vname: 'username',
                type: 'String',
                value: username,
            };
            params.push(username_);
            const signature_ = {
                vname: 'signature',
                type: 'ByStr64',
                value: signature,
            };
            params.push(signature_);
            return params;
        });
    }
    static Ivms101(username, message, signature) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const username_ = {
                vname: 'username',
                type: 'String',
                value: username,
            };
            params.push(username_);
            const message_ = {
                vname: 'message',
                type: 'String',
                value: message,
            };
            params.push(message_);
            const signature_ = {
                vname: 'signature',
                type: 'ByStr64',
                value: signature,
            };
            params.push(signature_);
            return params;
        });
    }
    static VerifiableCredential(username, signature) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = [];
            const username_ = {
                vname: 'username',
                type: 'String',
                value: username,
            };
            params.push(username_);
            const signature_ = {
                vname: 'signature',
                type: 'ByStr64',
                value: signature,
            };
            params.push(signature_);
            return params;
        });
    }
}
exports.default = TyronZIL;
var Option;
(function (Option) {
    Option["some"] = "Some";
    Option["none"] = "None";
})(Option = exports.Option || (exports.Option = {}));
var Recoverer;
(function (Recoverer) {
    Recoverer["first"] = "First";
    Recoverer["second"] = "Second";
})(Recoverer = exports.Recoverer || (exports.Recoverer = {}));
var BeneficiaryConstructor;
(function (BeneficiaryConstructor) {
    BeneficiaryConstructor["NftUsername"] = "NftUsername";
    BeneficiaryConstructor["Recipient"] = "Recipient";
})(BeneficiaryConstructor = exports.BeneficiaryConstructor || (exports.BeneficiaryConstructor = {}));
//# sourceMappingURL=tyronzil.js.map