"use strict";
/*
tyron.js: SSI Protocol's JavaScript/TypeScript library
Self-Sovereign Identity Protocol.
Copyright (C) Tyron Pungtas and its affiliates.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tyronzil = __importStar(require("../../blockchain/tyronzil"));
const document_model_1 = require("../protocols/models/document-model");
const hash_js_1 = __importDefault(require("hash.js"));
const zutil = __importStar(require("@zilliqa-js/util"));
/** Generates a `DID CRUD` operation
 *  which produces the `DID Document` & metadata */
class DidCrud {
    constructor(operation) {
        this.txParams = operation.txParams;
    }
    static GetServices(addr, services) {
        return __awaiter(this, void 0, void 0, function* () {
            let doc_elements = [];
            let doc_parameters = [];
            for (const service of services) {
                const doc_element = {
                    constructor: document_model_1.DocumentConstructor.Service,
                    action: document_model_1.Action.Add,
                    service: service,
                };
                doc_elements.push(doc_element);
                const doc_parameter = yield tyronzil.default.documentParameter(addr, doc_element);
                doc_parameters.push(doc_parameter);
            }
            return [doc_elements, doc_parameters];
        });
    }
    static Create(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const services_ = yield this.GetServices(input.addr, input.services);
            const document = input.verificationMethods.concat(services_[1]);
            const tx_params = yield tyronzil.default.CrudParams(input.addr, document, yield tyronzil.default.OptionParam(tyronzil.Option.none, 'ByStr64'), input.tyron_);
            const operation_output = {
                txParams: tx_params,
            };
            return new DidCrud(operation_output);
        });
    }
    static HashDocument(document) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            let hash_ = '0000000000000000000000000000000000000000';
            for (const element of document) {
                let action_;
                switch (element.action) {
                    case document_model_1.Action.Add:
                        action_ = 'add';
                        break;
                    case document_model_1.Action.Remove:
                        action_ = 'remove';
                        break;
                }
                const h1 = hash_js_1.default.sha256().update(action_).digest('hex');
                let h2;
                let h3;
                let hash__;
                switch (element.constructor) {
                    case document_model_1.DocumentConstructor.VerificationMethod:
                        h2 = hash_js_1.default.sha256().update((_a = element.key) === null || _a === void 0 ? void 0 : _a.id).digest('hex');
                        switch (element.action) {
                            case document_model_1.Action.Add:
                                h3 = hash_js_1.default
                                    .sha256()
                                    .update(zutil.bytes.hexToByteArray(element.key.key.substring(2)))
                                    .digest('hex');
                                const h4 = hash_js_1.default
                                    .sha256()
                                    .update((_b = element.key) === null || _b === void 0 ? void 0 : _b.encrypted)
                                    .digest('hex');
                                hash__ = h1 + h2 + h3 + h4;
                                break;
                            case document_model_1.Action.Remove:
                                hash__ = h1 + h2;
                                break;
                        }
                        break;
                    case document_model_1.DocumentConstructor.Service:
                        h2 = hash_js_1.default.sha256().update(element.service.id).digest('hex');
                        switch (element.action) {
                            case document_model_1.Action.Add:
                                switch (element.service.endpoint) {
                                    case 'Address':
                                        h3 = hash_js_1.default
                                            .sha256()
                                            .update(zutil.bytes.hexToByteArray(element.service.val.substring(2)))
                                            .digest('hex');
                                        break;
                                    case 'Uri':
                                        h3 = hash_js_1.default
                                            .sha256()
                                            .update(element.service.val)
                                            .digest('hex');
                                        break;
                                }
                                hash__ = h1 + h2 + h3;
                                break;
                            case document_model_1.Action.Remove:
                                hash__ = h1 + h2;
                                break;
                        }
                        break;
                }
                hash_ = hash_ + hash__;
            }
            return hash_;
        });
    }
    static Recover(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const services_ = yield this.GetServices(input.addr, input.services);
            const document = input.verificationMethods.concat(services_[1]);
            const tx_params = yield tyronzil.default.CrudParams(input.addr, document, yield tyronzil.default.OptionParam(tyronzil.Option.some, 'ByStr64', '0x' + input.signature), input.tyron_);
            const operation_output = {
                txParams: tx_params,
            };
            return new DidCrud(operation_output);
        });
    }
    static Deactivate(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const key_ = {
                id: 'deactivate',
                key: '0x024caf04aa4f660db04adf65daf5b993b3383fcdb2ef0479ca8866b1336334b5b4',
                encrypted: 'none',
            };
            const deactivate_element = {
                constructor: document_model_1.DocumentConstructor.VerificationMethod,
                action: document_model_1.Action.Add,
                key: key_,
            };
            const document = yield tyronzil.default.documentParameter(input.addr, deactivate_element);
            const tx_params = yield tyronzil.default.CrudParams(input.addr, [document], yield tyronzil.default.OptionParam(tyronzil.Option.some, 'ByStr64', '0x' + input.signature), input.tyron_);
            const operation_output = {
                txParams: tx_params,
            };
            return new DidCrud(operation_output);
        });
    }
}
exports.default = DidCrud;
//# sourceMappingURL=did-crud.js.map