import { ServiceModel } from '../../protocols/models/document-model';
import { DKMS, TyronVerificationMethods } from '../../protocols/models/verification-method-models';
import { NetworkNamespace } from '../../tyronzil-schemes/did-scheme';
import DidState from './did-state';
export declare enum Accept {
    contentType = "application/did+json",
    Result = "application/did+json;profile='https://w3c-ccg.github.io/did-resolution'"
}
/** Generates a Tyron DID Document */
export default class DidDoc {
    readonly id: string;
    readonly controller: string;
    readonly verificationMethods?: TyronVerificationMethods;
    readonly dkms?: DKMS;
    readonly services?: ServiceModel[];
    private constructor();
    /** The `Tyron DID Resolution` method */
    static resolution(network: NetworkNamespace, input: ResolutionInput): Promise<DidDoc | ResolutionResult>;
    /** Generates a 'Tyron DID Read' operation, resolving any Tyron DID State into its DID Document */
    static read(state: DidState): Promise<DidDoc>;
}
export interface ResolutionInput {
    addr: string;
    metadata: ResolutionInputMetadata;
}
export interface ResolutionInputMetadata {
    accept: Accept;
    versionId?: string;
    versionTime?: string;
    noCache?: boolean;
    dereferencingInput?: DereferencingInputMetadata;
}
interface DereferencingInputMetadata {
    serviceType?: string;
    followRedirect?: boolean;
}
export interface ResolutionResult {
    id: string;
    resolutionMetadata: unknown;
    document: DidDoc;
    metadata: DocumentMetadata;
}
interface DocumentMetadata {
    contentType: string;
}
export {};
