"use strict";
/*
    tyron.js: SSI Protocol's JavaScript/TypeScript library
    Self-Sovereign Identity Protocol.
    Copyright (C) Tyron Pungtas and its affiliates.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Accept = void 0;
const zcrypto = __importStar(require("@zilliqa-js/crypto"));
const zilliqa_init_1 = __importDefault(require("../../../blockchain/zilliqa-init"));
const verification_method_models_1 = require("../../protocols/models/verification-method-models");
const did_url_scheme_1 = __importDefault(require("../../tyronzil-schemes/did-url-scheme"));
const did_state_1 = __importDefault(require("./did-state"));
const ErrorCode_1 = __importDefault(require("../../util/ErrorCode"));
var Accept;
(function (Accept) {
    Accept["contentType"] = "application/did+json";
    Accept["Result"] = "application/did+json;profile='https://w3c-ccg.github.io/did-resolution'";
})(Accept = exports.Accept || (exports.Accept = {}));
/** Generates a Tyron DID Document */
class DidDoc {
    constructor(scheme) {
        this.id = scheme.id;
        this.controller = scheme.controller;
        this.verificationMethods = scheme.verificationMethods;
        this.dkms = scheme.dkms;
        this.services = scheme.services;
    }
    /** The `Tyron DID Resolution` method */
    static resolution(network, input) {
        return __awaiter(this, void 0, void 0, function* () {
            const ACCEPT = input.metadata.accept;
            const ZIL_INIT = new zilliqa_init_1.default(network);
            const BLOCKCHAIN_INFO = yield ZIL_INIT.API.blockchain.getBlockChainInfo();
            let RESOLUTION_RESULT;
            const DID_RESOLVED = yield did_state_1.default.fetch(network, input.addr)
                .then((did_state) => __awaiter(this, void 0, void 0, function* () {
                const DID_DOC = yield DidDoc.read(did_state);
                switch (ACCEPT) {
                    case Accept.contentType:
                        return DID_DOC;
                    case Accept.Result:
                        RESOLUTION_RESULT = {
                            id: DID_DOC.id,
                            resolutionMetadata: BLOCKCHAIN_INFO,
                            document: DID_DOC,
                            metadata: {
                                contentType: 'application/did+json',
                            },
                        };
                        return RESOLUTION_RESULT;
                }
            }))
                .catch((err) => {
                throw err;
            });
            return DID_RESOLVED;
        });
    }
    /** Generates a 'Tyron DID Read' operation, resolving any Tyron DID State into its DID Document */
    static read(state) {
        return __awaiter(this, void 0, void 0, function* () {
            const DID_DOC = yield did_url_scheme_1.default.validate(state.did)
                .then((did_scheme) => __awaiter(this, void 0, void 0, function* () {
                const ID = did_scheme.did;
                const VERIFICATION_METHODS = state.verification_methods;
                let PUBLIC_KEY = [];
                let AUTHENTICATION = [];
                let ASSERTION_METHOD = [];
                let KEY_AGREEMENT = [];
                let CAPABILITY_INVOCATION = [];
                let CAPABILITY_DELEGATION = [];
                let DID_UPDATE = [];
                let DID_RECOVERY = [];
                let SOCIAL_RECOVERY = [];
                if (typeof VERIFICATION_METHODS == typeof Map) {
                    const METHODS = VERIFICATION_METHODS;
                    // Every key MUST have a Public Key Purpose as its ID
                    for (let purpose of METHODS.keys()) {
                        const DID_URL = ID + '#' + purpose;
                        const KEY = METHODS.get(purpose);
                        let encrypted;
                        if (state.dkms === undefined) {
                            encrypted = 'undefined';
                        }
                        else {
                            encrypted = state.dkms.get(purpose);
                        }
                        const VERIFICATION_METHOD = {
                            id: DID_URL,
                            type: 'SchnorrSecp256k1VerificationKey2019',
                            publicKeyBase58: zcrypto.encodeBase58(KEY),
                        };
                        switch (purpose) {
                            case verification_method_models_1.PublicKeyPurpose.General:
                                PUBLIC_KEY = [VERIFICATION_METHOD, encrypted];
                                break;
                            case verification_method_models_1.PublicKeyPurpose.Auth:
                                AUTHENTICATION = [
                                    VERIFICATION_METHOD,
                                    encrypted,
                                ];
                                break;
                            case verification_method_models_1.PublicKeyPurpose.Assertion:
                                ASSERTION_METHOD = [
                                    VERIFICATION_METHOD,
                                    encrypted,
                                ];
                                break;
                            case verification_method_models_1.PublicKeyPurpose.Agreement:
                                KEY_AGREEMENT = [VERIFICATION_METHOD, encrypted];
                                break;
                            case verification_method_models_1.PublicKeyPurpose.Invocation:
                                CAPABILITY_INVOCATION = [
                                    VERIFICATION_METHOD,
                                    encrypted,
                                ];
                                break;
                            case verification_method_models_1.PublicKeyPurpose.Delegation:
                                CAPABILITY_DELEGATION = [
                                    VERIFICATION_METHOD,
                                    encrypted,
                                ];
                                break;
                            case verification_method_models_1.PublicKeyPurpose.Update:
                                DID_UPDATE = [VERIFICATION_METHOD, encrypted];
                                break;
                            case verification_method_models_1.PublicKeyPurpose.Recovery:
                                DID_RECOVERY = [VERIFICATION_METHOD, encrypted];
                                break;
                            case verification_method_models_1.PublicKeyPurpose.SocialRecovery:
                                SOCIAL_RECOVERY = [
                                    VERIFICATION_METHOD,
                                    encrypted,
                                ];
                                break;
                            default:
                                throw new ErrorCode_1.default('InvalidPurpose', `The resolver detected an invalid Public Key Purpose`);
                        }
                    }
                }
                const SERVICES = [];
                const services = state.services;
                if (typeof services == typeof Map) {
                    const services_map = services;
                    for (let id of services_map.keys()) {
                        const SERVICE = {
                            id: ID + '#' + id,
                            val: services_map.get(id),
                        };
                        SERVICES.push(SERVICE);
                    }
                }
                const services_ = state.services_;
                for (let id of services_.keys()) {
                    const TYPE_URI = services_.get(id);
                    const TYPE = TYPE_URI[0];
                    const URI = TYPE_URI[1];
                    const SERVICE = {
                        id: ID + '#' + id,
                        type: TYPE,
                        val: URI,
                    };
                    SERVICES.push(SERVICE);
                }
                /** The DID Document */
                const SCHEME = {
                    id: ID,
                    controller: state.controller,
                    verificationMethods: {},
                    dkms: {},
                    services: [],
                };
                if (PUBLIC_KEY !== []) {
                    SCHEME.verificationMethods.publicKey = PUBLIC_KEY[0];
                    SCHEME.dkms.publicKey = PUBLIC_KEY[1];
                }
                if (AUTHENTICATION !== []) {
                    SCHEME.verificationMethods.authentication =
                        AUTHENTICATION[0];
                    SCHEME.dkms.authentication = AUTHENTICATION[1];
                }
                if (ASSERTION_METHOD !== []) {
                    SCHEME.verificationMethods.assertionMethod =
                        ASSERTION_METHOD[0];
                    SCHEME.dkms.assertionMethod = ASSERTION_METHOD[1];
                }
                if (KEY_AGREEMENT !== []) {
                    SCHEME.verificationMethods.keyAgreement = KEY_AGREEMENT[0];
                    SCHEME.dkms.keyAgreement = KEY_AGREEMENT[1];
                }
                if (CAPABILITY_INVOCATION !== []) {
                    SCHEME.verificationMethods.capabilityInvocation =
                        CAPABILITY_INVOCATION[0];
                    SCHEME.dkms.capabilityInvocation = CAPABILITY_INVOCATION[1];
                }
                if (CAPABILITY_DELEGATION !== []) {
                    SCHEME.verificationMethods.capabilityDelegation =
                        CAPABILITY_DELEGATION[0];
                    SCHEME.dkms.capabilityDelegation = CAPABILITY_DELEGATION[1];
                }
                if (DID_UPDATE !== []) {
                    SCHEME.verificationMethods.didUpdate = DID_UPDATE[0];
                    SCHEME.dkms.didUpdate = DID_UPDATE[1];
                }
                if (DID_RECOVERY !== []) {
                    SCHEME.verificationMethods.didRecovery = DID_RECOVERY[0];
                    SCHEME.dkms.didRecovery = DID_RECOVERY[1];
                }
                if (SOCIAL_RECOVERY !== undefined) {
                    SCHEME.verificationMethods.socialRecovery =
                        SOCIAL_RECOVERY[0];
                    SCHEME.dkms.socialRecovery = SOCIAL_RECOVERY[1];
                }
                if (SERVICES.length !== 0) {
                    SCHEME.services = SERVICES;
                }
                return new DidDoc(SCHEME);
            }))
                .catch((err) => {
                throw err;
            });
            return DID_DOC;
        });
    }
}
exports.default = DidDoc;
//# sourceMappingURL=did-document.js.map