"use strict";
/*
tyron.js: SSI Protocol's JavaScript/TypeScript library
Self-Sovereign Identity Protocol.
Copyright (C) Tyron Pungtas and its affiliates.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const did_url_scheme_1 = __importDefault(require("../../tyronzil-schemes/did-url-scheme"));
const state_1 = __importDefault(require("../../../blockchain/state"));
/** The Tyron DID-State */
class DidState {
    constructor(state) {
        this.did = state.did;
        this.controller = state.controller;
        this.did_status = state.did_status;
        this.verification_methods = state.verification_methods;
        this.dkms = state.dkms;
        this.services = state.services;
        this.services_ = state.services_;
        this.did_recovery_key = state.did_recovery_key;
        this.did_update_key = state.did_update_key;
    }
    /** Fetches the current DID State for the given address */
    static fetch(network, addr) {
        return __awaiter(this, void 0, void 0, function* () {
            const did_state = yield state_1.default.fetch(network, addr)
                .then((state) => __awaiter(this, void 0, void 0, function* () {
                if (state.did !== '') {
                    // Validates the Tyron DID Scheme
                    yield did_url_scheme_1.default.validate(state.did);
                }
                const this_state = {
                    did: state.did,
                    controller: state.controller,
                    did_status: state.did_status,
                    verification_methods: state.verification_methods,
                    dkms: state.dkms,
                    services: state.services,
                    services_: state.services_,
                };
                if (typeof state.verification_methods === typeof Map) {
                    const methods = state.verification_methods;
                    this_state.did_recovery_key = methods.get('recovery');
                    this_state.did_update_key = methods.get('update');
                }
                return new DidState(this_state);
            }))
                .catch((err) => {
                throw err;
            });
            return did_state;
        });
    }
}
exports.default = DidState;
//# sourceMappingURL=did-state.js.map