"use strict";
/*
tyron.js: SSI Protocol's JavaScript/TypeScript library
Self-Sovereign Identity Protocol.
Copyright (C) Tyron Pungtas and its affiliates.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Sidetree = exports.DIDStatus = void 0;
const document_model_1 = require("./models/document-model");
const ErrorCode_1 = __importDefault(require("../util/ErrorCode"));
const tyronzil_1 = __importDefault(require("../../blockchain/tyronzil"));
const tyronzil_2 = __importDefault(require("../../blockchain/tyronzil"));
/** Operation types */
var DIDStatus;
(function (DIDStatus) {
    DIDStatus["Deployed"] = "Deployed";
    DIDStatus["Created"] = "Created";
    DIDStatus["Recovered"] = "Recovered";
    DIDStatus["Updated"] = "Updated";
    DIDStatus["Deactivated"] = "Deactivated";
    DIDStatus["Locked"] = "Locked";
})(DIDStatus = exports.DIDStatus || (exports.DIDStatus = {}));
class Sidetree {
    static processPatches(addr, patches) {
        return __awaiter(this, void 0, void 0, function* () {
            let doc_elements = [];
            let update_document = [];
            for (const patch of patches) {
                switch (patch.action) {
                    case document_model_1.PatchAction.RemoveKeys:
                        if (patch.ids !== undefined) {
                            for (const id of patch.ids) {
                                const key_ = {
                                    id: id,
                                };
                                const doc_element = {
                                    constructor: document_model_1.DocumentConstructor.VerificationMethod,
                                    action: document_model_1.Action.Remove,
                                    key: key_,
                                };
                                doc_elements.push(doc_element);
                                const doc_parameter = yield tyronzil_1.default.documentParameter(addr, doc_element);
                                update_document.push(doc_parameter);
                            }
                        }
                        break;
                    case document_model_1.PatchAction.AddServices:
                        if (patch.services !== undefined) {
                            for (const service of patch.services) {
                                const doc_element = {
                                    constructor: document_model_1.DocumentConstructor.Service,
                                    action: document_model_1.Action.Add,
                                    service: service,
                                };
                                doc_elements.push(doc_element);
                                const doc_parameter = yield tyronzil_2.default.documentParameter(addr, doc_element);
                                update_document.push(doc_parameter);
                            }
                        }
                        else {
                            throw new ErrorCode_1.default('Missing', 'No services given to add');
                        }
                        break;
                    case document_model_1.PatchAction.RemoveServices:
                        if (patch.ids !== undefined) {
                            for (const id of patch.ids) {
                                const service = { id: id };
                                const doc_element = {
                                    constructor: document_model_1.DocumentConstructor.Service,
                                    action: document_model_1.Action.Remove,
                                    service,
                                };
                                doc_elements.push(doc_element);
                                const doc_parameter = yield tyronzil_1.default.documentParameter(addr, doc_element);
                                update_document.push(doc_parameter);
                            }
                        }
                        else {
                            throw new ErrorCode_1.default('Missing', 'No service ID given to remove');
                        }
                        break;
                    default:
                        throw new ErrorCode_1.default('CodeIncorrectPatchAction', 'The chosen action is not valid.');
                }
            }
            return {
                documentElements: doc_elements,
                updateDocument: update_document,
            };
        });
    }
}
exports.Sidetree = Sidetree;
//# sourceMappingURL=sidetree.js.map