import { TransitionValue } from '../../blockchain/tyronzil';
import { DocumentElement } from '../protocols/models/document-model';
import { PrivateKeyModel, PublicKeyModel } from '../protocols/models/verification-method-models';
/** Defines input data to generate a cryptographic key pair */
export interface OperationKeyPairInput {
    id: string;
    addr: string;
}
/** Generates cryptographic operations */
export declare class Cryptography {
    /** Asymmetric cryptography to generate the key pair using the KEY_ALGORITHM (secp256k1)
     * @returns [verification method as TransitionValue, privateKey] */
    static operationKeyPair(input: OperationKeyPairInput): Promise<[DocumentElement, TransitionValue, PrivateKeyModel]>;
    /** Generates a secp256k1 key pair
     * @returns [publicKey, privateKey] */
    static keyPair(id: string): Promise<[string, PrivateKeyModel]>;
    static processKeys(input: PublicKeyModel[] | PrivateKeyModel[]): Promise<DIDVerificationMethods>;
}
export interface DIDVerificationMethods {
    didUpdate?: string;
    didRecovery?: string;
    didSocialRecovery?: string;
    general?: string;
    authentication?: string;
    assertion?: string;
    agreement?: string;
    invocation?: string;
    delegation?: string;
}
