"use strict";
/*
tyron.js: SSI Protocol's JavaScript/TypeScript library
Self-Sovereign Identity Protocol.
Copyright (C) Tyron Pungtas and its affiliates.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cryptography = void 0;
const zcrypto = __importStar(require("@zilliqa-js/crypto"));
const tyronzil_1 = __importDefault(require("../../blockchain/tyronzil"));
const document_model_1 = require("../protocols/models/document-model");
const verification_method_models_1 = require("../protocols/models/verification-method-models");
const ErrorCode_1 = __importDefault(require("./ErrorCode"));
/** Generates cryptographic operations */
class Cryptography {
    /** Asymmetric cryptography to generate the key pair using the KEY_ALGORITHM (secp256k1)
     * @returns [verification method as TransitionValue, privateKey] */
    static operationKeyPair(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const private_key = zcrypto.schnorr.generatePrivateKey();
            const public_key = '0x' + zcrypto.getPubKeyFromPrivateKey(private_key);
            const verification_method = {
                id: input.id,
                key: public_key,
                encrypted: private_key,
            };
            const doc_element = {
                constructor: document_model_1.DocumentConstructor.VerificationMethod,
                action: document_model_1.Action.Add,
                key: verification_method,
            };
            const doc_parameter = yield tyronzil_1.default.documentParameter(input.addr, doc_element);
            const private_key_model = {
                id: input.id,
                key: private_key,
            };
            return [doc_element, doc_parameter, private_key_model];
        });
    }
    /** Generates a secp256k1 key pair
     * @returns [publicKey, privateKey] */
    static keyPair(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const private_key = zcrypto.schnorr.generatePrivateKey();
            const public_key = zcrypto.getPubKeyFromPrivateKey(private_key);
            const private_key_model = {
                id: id,
                key: private_key,
            };
            return [public_key, private_key_model];
        });
    }
    static processKeys(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const key_id_set = new Set();
            let keys = {};
            let new_key;
            for (const key of input) {
                // IDs must be unique
                if (!key_id_set.has(key.id)) {
                    key_id_set.add(key.id);
                }
                else {
                    throw new ErrorCode_1.default('KeyDuplicated', 'The key ID must be unique');
                }
                switch (key.id) {
                    case verification_method_models_1.PublicKeyPurpose.General:
                        new_key = {
                            general: '0x' + key.key,
                        };
                        Object.assign(keys, new_key);
                        break;
                    case verification_method_models_1.PublicKeyPurpose.Auth:
                        new_key = {
                            authentication: '0x' + key.key,
                        };
                        Object.assign(keys, new_key);
                        break;
                    case verification_method_models_1.PublicKeyPurpose.Assertion:
                        new_key = {
                            assertion: '0x' + key.key,
                        };
                        Object.assign(keys, new_key);
                        break;
                    case verification_method_models_1.PublicKeyPurpose.Agreement:
                        new_key = {
                            agreement: '0x' + key.key,
                        };
                        Object.assign(keys, new_key);
                        break;
                    case verification_method_models_1.PublicKeyPurpose.Invocation:
                        new_key = {
                            invocation: '0x' + key.key,
                        };
                        Object.assign(keys, new_key);
                        break;
                    case verification_method_models_1.PublicKeyPurpose.Delegation:
                        new_key = {
                            delegation: '0x' + key.key,
                        };
                        Object.assign(keys, new_key);
                        break;
                    case verification_method_models_1.PublicKeyPurpose.Update:
                        new_key = {
                            did_update: key.key,
                        };
                        Object.assign(keys, new_key);
                        break;
                    case verification_method_models_1.PublicKeyPurpose.Recovery:
                        new_key = {
                            did_recovery: key.key,
                        };
                        Object.assign(keys, new_key);
                        break;
                    case verification_method_models_1.PublicKeyPurpose.SocialRecovery:
                        new_key = {
                            did_social_recovery: key.key,
                        };
                        Object.assign(keys, new_key);
                        break;
                    default:
                        throw new ErrorCode_1.default('InvalidID', `The client detected an invalid key ID.`);
                }
            }
            return keys;
        });
    }
}
exports.Cryptography = Cryptography;
//# sourceMappingURL=did-keys.js.map